@@ -11,7 +11,7 @@ use warnings;
 use strict;
 
 package Audio::MPD;
-our $VERSION = '1.092950';
+our $VERSION = '1.093170';
 
 
 # ABSTRACT: class to talk to MPD (Music Player Daemon) servers
@@ -21,28 +21,31 @@ use Audio::MPD::Common::Item;
 use Audio::MPD::Common::Stats;
 use Audio::MPD::Common::Status;
 use Audio::MPD::Playlist;
+use Audio::MPD::Types;
 use Encode;
 use IO::Socket;
 use Moose;
-use Moose::Util::TypeConstraints;
+use MooseX::Has::Sugar;
 use MooseX::SemiAffordanceAccessor;
 
 
-has _socket    => ( is=>'rw', isa=>'IO::Socket::INET' );
 
-enum CONNTYPE  => qw{ reuse once };
-has conntype   => ( is=>'ro', isa=>'CONNTYPE', default=>'once'  );
-has host       => ( is=>'ro', lazy_build=>1 );
-has password   => ( is=>'rw', lazy_build=>1, trigger=>sub { $_[0]->ping } );
-has port       => ( is=>'ro', lazy_build=>1 );
-has collection => ( is=>'ro', lazy_build=>1, isa=>'Audio::MPD::Collection' );
-has playlist   => ( is=>'ro', lazy_build=>1, isa=>'Audio::MPD::Playlist'   );
-has version    => ( is=>'rw' );
+has conntype   => ( ro, isa=>'CONNTYPE', default=>'once'  );
+has host       => ( ro, lazy_build );
+has password   => ( rw, lazy_build, trigger=>sub { $_[0]->ping } );
+has port       => ( ro, lazy_build );
+
+has collection => ( ro, lazy_build, isa=>'Audio::MPD::Collection' );
+has playlist   => ( ro, lazy_build, isa=>'Audio::MPD::Playlist'   );
+has version    => ( rw );
+
+has _socket    => ( rw, isa=>'IO::Socket::INET' );
 
 
 #--
 # initializer & lazy builders
 
+
 sub BUILD {
     my $self = shift;
 
@@ -70,6 +73,7 @@ sub _parse_env_var {
 sub _build_host     { return ( _parse_env_var() )[1] || 'localhost'; }
 sub _build_port     { return $ENV{MPD_PORT}     || ( _parse_env_var() )[2] || 6600; }
 sub _build_password { return $ENV{MPD_PASSWORD} || ( _parse_env_var() )[0] || '';   }
+
 sub _build_collection { Audio::MPD::Collection->new( _mpd => $_[0] ); }
 sub _build_playlist   { Audio::MPD::Playlist  ->new( _mpd => $_[0] ); }
 
@@ -222,53 +226,32 @@ sub _cooked_command_strip_first_field {
 
 # -- MPD interaction: general commands
 
-#
-# $mpd->ping;
-#
-# Sends a ping command to the mpd server.
-#
+
 sub ping {
     my ($self) = @_;
     $self->_send_command( "ping\n" );
 }
 
 
-#
-# my $version = $mpd->version;
-#
-# Return version of MPD server's connected.
-#
+
+
 # sub version {} # implemented as an accessor.
-#
 
 
-#
-# $mpd->kill;
-#
-# Send a message to the MPD server telling it to shut down.
-#
+
+
 sub kill {
     my ($self) = @_;
     $self->_send_command("kill\n");
 }
 
 
-#
-# $mpd->set_password( [$password] )
-#
-# Change password used to communicate with MPD server to $password.
-# Empty string is assumed if $password is not supplied.
-#
+
+
 # implemented by password trigger (from moose)
 
 
-#
-# $mpd->updatedb( [$path] );
-#
-# Force mpd to rescan its collection. If $path (relative to MPD's music
-# directory) is supplied, MPD will only scan it - otherwise, MPD will rescan
-# its whole collection.
-#
+
 sub updatedb {
     my ($self, $path) = @_;
     $path ||= '';
@@ -276,11 +259,7 @@ sub updatedb {
 }
 
 
-#
-# my @handlers = $mpd->urlhandlers;
-#
-# Return an array of supported URL schemes.
-#
+
 sub urlhandlers {
     my ($self) = @_;
     return $self->_cooked_command_strip_first_field("urlhandlers\n");
@@ -289,13 +268,7 @@ sub urlhandlers {
 
 # -- MPD interaction: handling volume & output
 
-#
-# $mpd->volume( [+][-]$volume );
-#
-# Sets the audio output volume percentage to absolute $volume.
-# If $volume is prefixed by '+' or '-' then the volume is changed relatively
-# by that value.
-#
+
 sub volume {
     my ($self, $volume) = @_;
 
@@ -307,22 +280,14 @@ sub volume {
 }
 
 
-#
-# $mpd->output_enable( $output );
-#
-# Enable the specified audio output. $output is the ID of the audio output.
-#
+
 sub output_enable {
     my ($self, $output) = @_;
     $self->_send_command("enableoutput $output\n");
 }
 
 
-#
-# $mpd->output_disable( $output );
-#
-# Disable the specified audio output. $output is the ID of the audio output.
-#
+
 sub output_disable {
     my ($self, $output) = @_;
     $self->_send_command("disableoutput $output\n");
@@ -332,11 +297,7 @@ sub output_disable {
 
 # -- MPD interaction: retrieving info from current state
 
-#
-# $mpd->stats;
-#
-# Return an AMC::Stats object with the current statistics of MPD.
-#
+
 sub stats {
     my ($self) = @_;
     my %kv = $self->_cooked_command_as_kv( "stats\n" );
@@ -344,13 +305,7 @@ sub stats {
 }
 
 
-#
-# my $status = $mpd->status;
-#
-# Return an AMC::Status object with various information on current
-# MPD server settings. Check the embedded pod for more information on the
-# available accessors.
-#
+
 sub status {
     my ($self) = @_;
     my %kv = $self->_cooked_command_as_kv( "status\n" );
@@ -359,11 +314,7 @@ sub status {
 }
 
 
-#
-# my $song = $mpd->current;
-#
-# Return an AMC::Item::Song representing the song currently playing.
-#
+
 sub current {
     my ($self) = @_;
     my ($item) = $self->_cooked_command_as_items("currentsong\n");
@@ -371,12 +322,7 @@ sub current {
 }
 
 
-#
-# my $song = $mpd->song( [$song] )
-#
-# Return an AMC::Item::Song representing the song number $song.
-# If $song is not supplied, returns the current song.
-#
+
 sub song {
     my ($self, $song) = @_;
     return $self->current unless defined $song;
@@ -385,12 +331,7 @@ sub song {
 }
 
 
-#
-# my $song = $mpd->songid( [$songid] )
-#
-# Return an AMC::Item::Song representing the song with id $songid.
-# If $songid is not supplied, returns the current song.
-#
+
 sub songid {
     my ($self, $songid) = @_;
     return $self->current unless defined $songid;
@@ -401,12 +342,8 @@ sub songid {
 
 # -- MPD interaction: altering settings
 
-#
-# $mpd->repeat( [$repeat] );
-#
-# Set the repeat mode to $repeat (1 or 0). If $repeat is not specified then
-# the repeat mode is toggled.
-#
+
+
 sub repeat {
     my ($self, $mode) = @_;
 
@@ -417,12 +354,7 @@ sub repeat {
 }
 
 
-#
-# $mpd->random( [$random] );
-#
-# Set the random mode to $random (1 or 0). If $random is not specified then
-# the random mode is toggled.
-#
+
 sub random {
     my ($self, $mode) = @_;
 
@@ -433,12 +365,7 @@ sub random {
 }
 
 
-#
-# $mpd->fade( [$seconds] );
-#
-# Enable crossfading and set the duration of crossfade between songs. If
-# $seconds is not specified or $seconds is 0, then crossfading is disabled.
-#
+
 sub fade {
     my ($self, $value) = @_;
     $value ||= 0;
@@ -448,24 +375,15 @@ sub fade {
 
 # -- MPD interaction: controlling playback
 
-#
-# $mpd->play( [$song] );
-#
-# Begin playing playlist at song number $song. If no argument supplied,
-# resume playing.
-#
+
 sub play {
     my ($self, $number) = @_;
     $number = '' unless defined $number;
     $self->_send_command("play $number\n");
 }
 
-#
-# $mpd->playid( [$songid] );
-#
-# Begin playing playlist at song ID $songid. If no argument supplied,
-# resume playing.
-#
+
+
 sub playid {
     my ($self, $number) = @_;
     $number ||= '';
@@ -473,14 +391,7 @@ sub playid {
 }
 
 
-#
-# $mpd->pause( [$sate] );
-#
-# Pause playback. If $state is 0 then the current track is unpaused, if
-# $state is 1 then the current track is paused.
-#
-# Note that if $state is not given, pause state will be toggled.
-#
+
 sub pause {
     my ($self, $state) = @_;
     $state ||= ''; # default is to toggle
@@ -488,44 +399,28 @@ sub pause {
 }
 
 
-#
-# $mpd->stop;
-#
-# Stop playback.
-#
+
 sub stop {
     my ($self) = @_;
     $self->_send_command("stop\n");
 }
 
 
-#
-# $mpd->next;
-#
-# Play next song in playlist.
-#
+
 sub next {
     my ($self) = @_;
     $self->_send_command("next\n");
 }
 
-#
-# $mpd->prev;
-#
-# Play previous song in playlist.
-#
+
+
 sub prev {
     my($self) = shift;
     $self->_send_command("previous\n");
 }
 
 
-#
-# $mpd->seek( $time, [$song] );
-#
-# Seek to $time seconds in song number $song. If $song number is not specified
-# then the perl module will try and seek to $time in the current song.
-#
+
 sub seek {
     my ($self, $time, $song) = @_;
     $time ||= 0; $time = int $time;
@@ -534,12 +429,7 @@ sub seek {
 }
 
 
-#
-# $mpd->seekid( $time, [$songid] );
-#
-# Seek to $time seconds in song ID $songid. If $songid number is not specified
-# then the perl module will try and seek to $time in the current song.
-#
+
 sub seekid {
     my ($self, $time, $song) = @_;
     $time ||= 0; $time = int $time;
@@ -554,7 +444,6 @@ __PACKAGE__->meta->make_immutable;
 
 
 
-
 =pod
 
 =head1 NAME
@@ -563,13 +452,7 @@ Audio::MPD - class to talk to MPD (Music Player Daemon) servers
 
 =head1 VERSION
 
-version 1.092950
-
-=begin Pod::Coverage
-
-BUILD
-
-=end Pod::Coverage
+version 1.093170
 
 =head1 SYNOPSIS
 
@@ -587,7 +470,7 @@ controlling MPD (Music Player Daemon) servers. A connection to the MPD
 server is established as soon as a new L<Audio::MPD> object is created.
 
 Since mpd is still in 0.x versions, L<Audio::MPD> sticks to latest mpd
-(0.14 as time of writing) protocol & behaviour, and does B<not> try to
+(0.15 as time of writing) protocol & behaviour, and does B<not> try to
 maintain backward compatibility.
 
 Note that the module will by default connect to mpd before sending any
@@ -605,204 +488,6 @@ to use it instead of L<Audio::MPD>. Or you can try to set C<conntype> to
 C<$REUSE> (see L<Audio::MPD> constructor for more details), but you
 would be then on your own to deal with disconnections.
 
-=head1 METHODS
-
-=head2 Constructor
-
-=over 4
-
-=item new( [%opts] )
-
-This is the constructor for L<Audio::MPD>. One can specify the following
-options:
-
-=over 4
-
-=item host => $hostname
-
-defaults to environment var C<MPD_HOST>, then to 'localhost'. Note that
-C<MPD_HOST> can be of the form C<password@host:port> (each of
-C<password@> or C<:port> can be omitted).
-
-=item port => $port
-
-defaults to environment var C<MPD_PORT>, then to parsed C<MPD_HOST>,
-then to 6600.
-
-=item password => $password
-
-defaults to environment var C<MPD_PASSWORD>, then to parsed C<MPD_HOST>,
-then to empty string.
-
-=item conntype => $type
-
-change how the connection to mpd server is handled. It can be either the
-C<reuse> string to reuse the same connection or C<once> to open a new
-connection per command (default).
-
-=back 
-
-=back 
-
-=head2 Controlling the server
-
-=over 4
-
-=item $mpd->ping()
-
-Sends a ping command to the mpd server.
-
-=item $mpd->version()
-
-Return mpd's version number as advertised during connection. Note that
-mpd returns B<protocol> version when connected. This protocol version
-can differ from the real mpd version. eg, mpd version 0.13.2 is
-"speaking" and thus advertising version 0.13.0.
-
-=item $mpd->kill()
-
-Send a message to the MPD server telling it to shut down.
-
-=item $mpd->set_password( [$password] )
-
-Change password used to communicate with MPD server to C<$password>.
-Empty string is assumed if C<$password> is not supplied.
-
-=item $mpd->updatedb( [$path] )
-
-Force mpd to recan its collection. If C<$path> (relative to MPD's music
-directory) is supplied, MPD will only scan it - otherwise, MPD will
-rescan its whole collection.
-
-=item $mpd->urlhandlers()
-
-Return an array of supported URL schemes.
-
-=back 
-
-=head2 Handling volume & output
-
-=over 4
-
-=item $mpd->volume( [+][-]$volume )
-
-Sets the audio output volume percentage to absolute C<$volume>.  If
-C<$volume> is prefixed by '+' or '-' then the volume is changed
-relatively by that value.
-
-=item $mpd->output_enable( $output )
-
-Enable the specified audio output. C<$output> is the ID of the audio
-output.
-
-=item $mpd->output_disable( $output )
-
-Disable the specified audio output. C<$output> is the ID of the audio
-output.
-
-=back 
-
-=head2 Retrieving info from current state
-
-=over 4
-
-=item $mpd->stats()
-
-Return an L<Audio::MPD::Common::Stats> object with the current statistics
-of MPD. See the associated pod for more information.
-
-=item $mpd->status()
-
-Return an L<Audio::MPD::Common::Status> object with various information on
-current MPD server settings. Check the embedded pod for more information on
-the available accessors.
-
-=item $mpd->current()
-
-Return an L<Audio::MPD::Common::Item::Song> representing the song currently
-playing.
-
-=item $mpd->song( [$song] )
-
-Return an L<Audio::MPD::Common::Item::Song> representing the song number
-C<$song>. If C<$song> is not supplied, returns the current song.
-
-=item $mpd->songid( [$songid] )
-
-Return an L<Audio::MPD::Common::Item::Song> representing the song with id
-C<$songid>. If C<$songid> is not supplied, returns the current song.
-
-=back 
-
-=head2 Altering MPD settings
-
-=over 4
-
-=item $mpd->repeat( [$repeat] )
-
-Set the repeat mode to C<$repeat> (1 or 0). If C<$repeat> is not
-specified then the repeat mode is toggled.
-
-=item $mpd->random( [$random] )
-
-Set the random mode to C<$random> (1 or 0). If C<$random> is not
-specified then the random mode is toggled.
-
-=item $mpd->fade( [$seconds] )
-
-Enable crossfading and set the duration of crossfade between songs.  If
-C<$seconds> is not specified or $seconds is 0, then crossfading is
-disabled.
-
-=back 
-
-=head2 Controlling playback
-
-=over 4
-
-=item $mpd->play( [$song] )
-
-Begin playing playlist at song number C<$song>. If no argument supplied,
-resume playing.
-
-=item $mpd->playid( [$songid] )
-
-Begin playing playlist at song ID C<$songid>. If no argument supplied,
-resume playing.
-
-=item $mpd->pause( [$state] )
-
-Pause playback. If C<$state> is 0 then the current track is unpaused,
-if C<$state> is 1 then the current track is paused.
-
-Note that if C<$state> is not given, pause state will be toggled.
-
-=item $mpd->stop()
-
-Stop playback.
-
-=item $mpd->next()
-
-Play next song in playlist.
-
-=item $mpd->prev()
-
-Play previous song in playlist.
-
-=item $mpd->seek( $time, [$song])
-
-Seek to C<$time> seconds in song number C<$song>. If C<$song> number is
-not specified then the perl module will try and seek to C<$time> in the
-current song.
-
-=item $mpd->seekid( $time, $songid )
-
-Seek to C<$time> seconds in song ID C<$songid>. If C<$song> number is
-not specified then the perl module will try and seek to C<$time> in the
-current song.
-
-=back 
-
 =head2 Searching the collection
 
 To search the collection, use the C<collection()> accessor, returning the
@@ -823,6 +508,180 @@ associated L<Audio::MPD::Playlist> object. You will then be able to call:
 See L<Audio::MPD::Playlist> documentation for more details on available
 methods.
 
+=head1 ATTRIBUTES
+
+=head2 host
+
+The hostname where MPD is running. Defaults to environment var
+C<MPD_HOST>, then to 'localhost'. Note that C<MPD_HOST> can be of
+the form C<password@host:port> (each of C<password@> or C<:port> can
+be omitted).
+
+=head2 port
+
+The port that MPD server listens to. Defaults to environment var
+C<MPD_PORT>, then to parsed C<MPD_HOST> (cf above), then to 6600.
+
+=head2 password
+
+The password to access special MPD functions. Defaults to environment
+var C<MPD_PASSWORD>, then to parsed C<MPD_HOST> (cf above), then to
+empty string.
+
+=head2 conntype
+
+Change how the connection to mpd server is handled. It should be of a
+C<CONNTYPE> type (cf L<Audio::MPD::Types>). Use either the C<reuse>
+string to reuse the same connection or C<once> to open a new connection
+per command (default).
+
+=head1 METHODS
+
+=head2 my $mpd = Audio::MPD->new( \%opts );
+
+This is the constructor for L<Audio::MPD>. One can specify any of the
+attributes (cf above).
+
+=head1 CONTROLLING THE SERVER
+
+=head2 $mpd->ping;
+
+Sends a ping command to the mpd server.
+
+=head2 my $version = $mpd->version;
+
+Return mpd's version number as advertised during connection. Note that
+mpd returns B<protocol> version when connected. This protocol version
+can differ from the real mpd version. eg, mpd version 0.13.2 is
+"speaking" and thus advertising version 0.13.0.
+
+=head2 $mpd->kill;
+
+Send a message to the MPD server telling it to shut down.
+
+=head2 $mpd->set_password( [$password] );
+
+Change password used to communicate with MPD server to C<$password>.
+Empty string is assumed if C<$password> is not supplied.
+
+=head2 $mpd->updatedb( [$path] );
+
+Force mpd to recan its collection. If C<$path> (relative to MPD's music
+directory) is supplied, MPD will only scan it - otherwise, MPD will
+rescan its whole collection.
+
+=head2 my @handlers = $mpd->urlhandlers;
+
+Return an array of supported URL schemes.
+
+=head1 HANDLING VOLUME & OUTPUT
+
+=head2 $mpd->volume( [+][-]$volume );
+
+Sets the audio output volume percentage to absolute C<$volume>.  If
+C<$volume> is prefixed by '+' or '-' then the volume is changed
+relatively by that value.
+
+=head2 $mpd->output_enable( $output );
+
+Enable the specified audio output. C<$output> is the ID of the audio
+output.
+
+=head2 $mpd->output_disable( $output );
+
+Disable the specified audio output. C<$output> is the ID of the audio
+output.
+
+=head1 RETRIEVING INFO FROM CURRENT STATE
+
+=head2 my $stats = $mpd->stats;
+
+Return an L<Audio::MPD::Common::Stats> object with the current statistics
+of MPD. See the associated pod for more information.
+
+=head2 my $status = $mpd->status;
+
+Return an L<Audio::MPD::Common::Status> object with various information on
+current MPD server settings. See the associated pod for more information.
+
+=head2 my $song = $mpd->current;
+
+Return an L<Audio::MPD::Common::Item::Song> representing the song currently
+playing.
+
+=head2 my $song = $mpd->song( [$song] );
+
+Return an L<Audio::MPD::Common::Item::Song> representing the song number
+C<$song>. If C<$song> is not supplied, returns the current song.
+
+=head2 my $song = $mpd->songid( [$songid] );
+
+Return an L<Audio::MPD::Common::Item::Song> representing the song with id
+C<$songid>. If C<$songid> is not supplied, returns the current song.
+
+=head1 ALTERING MPD SETTINGS
+
+=head2 $mpd->repeat( [$repeat] );
+
+Set the repeat mode to C<$repeat> (1 or 0). If C<$repeat> is not
+specified then the repeat mode is toggled.
+
+=head2 $mpd->random( [$random] );
+
+Set the random mode to C<$random> (1 or 0). If C<$random> is not
+specified then the random mode is toggled.
+
+=head2 $mpd->fade( [$seconds] );
+
+Enable crossfading and set the duration of crossfade between songs.  If
+C<$seconds> is not specified or $seconds is 0, then crossfading is
+disabled.
+
+=head1 CONTROLLING PLAYBACK
+
+=head2 $mpd->play( [$song] );
+
+Begin playing playlist at song number C<$song>. If no argument supplied,
+resume playing.
+
+=head2 $mpd->playid( [$songid] );
+
+Begin playing playlist at song ID C<$songid>. If no argument supplied,
+resume playing.
+
+=head2 $mpd->pause( [$state] );
+
+Pause playback. If C<$state> is 0 then the current track is unpaused,
+if C<$state> is 1 then the current track is paused.
+
+Note that if C<$state> is not given, pause state will be toggled.
+
+=head2 $mpd->stop;
+
+Stop playback.
+
+=head2 $mpd->next;
+
+Play next song in playlist.
+
+=head2 $mpd->prev;
+
+Play previous song in playlist.
+
+=head2 $mpd->seek( $time, [$song]);
+
+Seek to C<$time> seconds in song number C<$song>. If C<$song> number is
+not specified then the perl module will try and seek to C<$time> in the
+current song.
+
+=head2 $mpd->seekid( $time, $songid );
+
+Seek to C<$time> seconds in song ID C<$songid>. If C<$song> number is
+not specified then the perl module will try and seek to C<$time> in the
+current song.
+
+=for Pod::Coverage BUILD
+
 =head1 SEE ALSO
 
 You can find more information on the mpd project on its homepage at
@@ -852,7 +711,7 @@ L<http://cpanratings.perl.org/d/Audio-MPD>
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Audio-MPD>
 
-=back 
+=back
 
 =head1 AUTHOR
 
@@ -865,8 +724,7 @@ This software is copyright (c) 2007 by Jerome Quelin.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
 
 __END__
\ No newline at end of file
